api.documents.v1.document package — Argus-Toolbelt 1.0 documentation

# api.documents.v1.document package

## Submodules

## api.documents.v1.document.document module

Autogenerated API

`api.documents.v1.document.document.` `commit_document`(documentID: int, name: str = None, mimeType: str = None, data: str = None, text: str = None, lockRequestTime: int = 300000, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Commit specified document (PUBLIC)

  Return type: | `dict`
  Parameters: | documentID (int) – ID of document to commit name (str) – If set change document name => Sanitize by regex [a-zA-Z0-9ÅåØøÆæ_-. ]* mimeType (str) – If set change document MIME type data (str) – Base64 encoded document content formatted according to the given MIME type. If set change document content text (str) – Plain text document content. If set change document content lockRequestTime (int) – Specify how long the document should be locked (default 300000)
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 Exception – on 423 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 818, “limit”: 767, “responseCode”: 200, “count”: 380, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Country join certainly.”, “messageTemplate”: “Process human friend again present lose.”, “field”: “Team policy life.”, “parameter”: {}, “timestamp”: 797858429}], “currentPage”: 135, “size”: 749}

`api.documents.v1.document.document.` `get_document_content_by_id`(documentID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Download content as a file for specified document (PUBLIC)

  Return type: | `dict`
  Parameters: | documentID (int) – ID of document to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.documents.v1.document.document.` `get_document_revisions`(documentID: int, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch specified document revisions (PUBLIC)

  Return type: | `dict`
  Parameters: | documentID (int) – ID of document to fetch revisions limit (int) – Maximum number of returned results offset (int) – Skip a number of results
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 319, “limit”: 859, “responseCode”: 200, “count”: 775, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Kind hope up send more.”, “messageTemplate”: “Edge cultural check contain team.”, “field”: “Be into bring finish appear.”, “parameter”: {}, “timestamp”: 2648399}], “currentPage”: 497, “size”: 54}

`api.documents.v1.document.document.` `get_meta_info_by_id`(documentID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch specified document excluding content (PUBLIC)

  Return type: | `dict`
  Parameters: | documentID (int) – ID of document to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 265, “limit”: 880, “responseCode”: 200, “count”: 512, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Ten term laugh whom owner across road.”, “messageTemplate”: “Statement should wrong go a.”, “field”: “Enter catch according dinner part.”, “parameter”: {}, “timestamp”: 969614494}], “currentPage”: 809, “size”: 924}

`api.documents.v1.document.document.` `grant_document_access`(documentID: int, subjectID: int = None, level: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Grant access to specified document (PUBLIC) If the access level is folder, the user is allowed to obtain the information about the document (without content). If the access level is read, the user is allowed to obtain the content of the document. If the access level is write, the user is allowed to update the document.

  Return type: | `dict`

`api.documents.v1.document.document.` `list_document_access`(documentID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch ACL for specified document (PUBLIC)

  Return type: | `dict`
  Parameters: | documentID (int) – Document ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 110, “limit”: 13, “responseCode”: 200, “count”: 852, “data”: [{“id”: 205, “subject”: {“id”: 427, “customerID”: 952, “name”: “Thomas Jones”}, “level”: “write”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Trip despite recognize range.”, “messageTemplate”: “Finish soldier one over.”, “field”: “Foot lead hundred recent kitchen member car.”, “parameter”: {}, “timestamp”: 1341714018}], “currentPage”: 277, “size”: 825}

`api.documents.v1.document.document.` `lock_document`(documentID: int, lockRequestTime: int = None, mode: str = 'LOCK', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Lock/Unlock specified document (PUBLIC)

  Return type: | `dict`
  Parameters: | documentID (int) – ID of document to lock/unlock lockRequestTime (int) – If ‘mode’ is set to LOCK, specify how long the document should be locked mode (str) – Specify whether to lock or unlock the document, or to override an existing lock (default LOCK)
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 Exception – on 423 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 391, “limit”: 789, “responseCode”: 200, “count”: 121, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Part thought who bring up so.”, “messageTemplate”: “Choose really back.”, “field”: “Rock officer my rock save her.”, “parameter”: {}, “timestamp”: 1102556181}], “currentPage”: 791, “size”: 273}

`api.documents.v1.document.document.` `revoke_document_access`(documentID: int, accessID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Revoke specified explicit access from document (PUBLIC)

  Return type: | `dict`
  Parameters: | documentID (int) – Document ID accessID (int) – Access ID
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 240, “limit”: 607, “responseCode”: 200, “count”: 227, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Wear Mr brother despite few plant.”, “messageTemplate”: “Fish cup including sign.”, “field”: “Hotel relationship energy listen while indicate.”, “parameter”: {}, “timestamp”: 1447789523}], “currentPage”: 663, “size”: 28}

`api.documents.v1.document.document.` `update_document`(documentID: int, name: str = None, mimeType: str = None, data: str = None, text: str = None, lockRequestTime: int = 300000, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update specified document (PUBLIC)

  Return type: | `dict`
  Parameters: | documentID (int) – ID of document to update name (str) – If set change document name => Sanitize by regex [a-zA-Z0-9ÅåØøÆæ_-. ]* mimeType (str) – If set change document MIME type data (str) – Base64 encoded document content formatted according to the given MIME type. If set change document content text (str) – Plain text document content. If set change document content lockRequestTime (int) – Specify how long the document should be locked (default 300000)
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 Exception – on 423 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 474, “limit”: 974, “responseCode”: 200, “count”: 219, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Tax resource maintain her big.”, “messageTemplate”: “Difficult high event effect.”, “field”: “With organization ready both scene red former.”, “parameter”: {}, “timestamp”: 796802119}], “currentPage”: 874, “size”: 45}

`api.documents.v1.document.document.` `update_document_access_settings`(documentID: int, accessMode: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Change access settings on specified document (PUBLIC) If the access mode is roleBased, user accessing the document must have appropriate role, set by administrator. If the access mode is writeRestricted, user accessing the document can read, but must have appropriate role for write, set by administrator. If the access mode is readRestricted, user accessing the document must have appropriate roles for both read and write, set by administrator. If the access mode is explicit, user accessing the document must have explicit grant by document’s owner.

  Return type: | `dict`

## Module contents